==> openshift-model-operator-6.8.0-sources.jar: io/fabric8/openshift/api/model/operator/v1/DNSCacheFluent.java <==
package io.fabric8.openshift.api.model.operator.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.model.Duration;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class DNSCacheFluent<A extends DNSCacheFluent<A>> extends BaseFluent<A>{
  public DNSCacheFluent() {
  }
  public DNSCacheFluent(DNSCache instance) {
    instance = (instance != null ? instance : new DNSCache());

    if (instance != null) {
      this.withNegativeTTL(instance.getNegativeTTL());
      this.withPositiveTTL(instance.getPositiveTTL());
      this.withNegativeTTL(instance.getNegativeTTL());
      this.withPositiveTTL(instance.getPositiveTTL());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private Duration negativeTTL;
  private Duration positiveTTL;
  private Map<String,Object> additionalProperties;
  public Duration getNegativeTTL() {
    return this.negativeTTL;
  }
  public A withNegativeTTL(Duration negativeTTL) {
    this.negativeTTL=negativeTTL; return (A) this;
  }
  public boolean hasNegativeTTL() {
    return this.negativeTTL != null;
  }
  public Duration getPositiveTTL() {
    return this.positiveTTL;
  }
  public A withPositiveTTL(Duration positiveTTL) {
    this.positiveTTL=positiveTTL; return (A) this;
  }
  public boolean hasPositiveTTL() {
    return this.positiveTTL != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    DNSCacheFluent that = (DNSCacheFluent) o;
    if (!java.util.Objects.equals(negativeTTL, that.negativeTTL)) return false;

    if (!java.util.Objects.equals(positiveTTL, that.positiveTTL)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(negativeTTL,  positiveTTL,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (negativeTTL != null) { sb.append("negativeTTL:"); sb.append(negativeTTL + ","); }
    if (positiveTTL != null) { sb.append("positiveTTL:"); sb.append(positiveTTL + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> openshift-model-operator-6.9.0-sources.jar: io/fabric8/openshift/api/model/operator/v1/DNSCacheFluent.java <==
package io.fabric8.openshift.api.model.operator.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.model.Duration;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class DNSCacheFluent<A extends DNSCacheFluent<A>> extends BaseFluent<A>{
  public DNSCacheFluent() {
  }
  
  public DNSCacheFluent(DNSCache instance) {
    this.copyInstance(instance);
  }
  private Duration negativeTTL;
  private Duration positiveTTL;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(DNSCache instance) {
    instance = (instance != null ? instance : new DNSCache());
  
    if (instance != null) {
        this.withNegativeTTL(instance.getNegativeTTL());
        this.withPositiveTTL(instance.getPositiveTTL());
        this.withNegativeTTL(instance.getNegativeTTL());
        this.withPositiveTTL(instance.getPositiveTTL());
        this.withAdditionalProperties(instance.getAdditionalProperties());
      }
  }
  
  public Duration getNegativeTTL() {
    return this.negativeTTL;
  }
  
  public A withNegativeTTL(Duration negativeTTL) {
    this.negativeTTL=negativeTTL; return (A) this;
  }
  
  public boolean hasNegativeTTL() {
    return this.negativeTTL != null;
  }
  
  public Duration getPositiveTTL() {
    return this.positiveTTL;
  }
  
  public A withPositiveTTL(Duration positiveTTL) {
    this.positiveTTL=positiveTTL; return (A) this;
  }
  
  public boolean hasPositiveTTL() {
    return this.positiveTTL != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    DNSCacheFluent that = (DNSCacheFluent) o;
    if (!java.util.Objects.equals(negativeTTL, that.negativeTTL)) return false;
  
    if (!java.util.Objects.equals(positiveTTL, that.positiveTTL)) return false;
  
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(negativeTTL,  positiveTTL,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (negativeTTL != null) { sb.append("negativeTTL:"); sb.append(negativeTTL + ","); }
    if (positiveTTL != null) { sb.append("positiveTTL:"); sb.append(positiveTTL + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  

}
